@@ -1,8 +1,6 @@
-"EvalScaleFunction" <-
-function (method)
+EvalScaleFunction <- function (method)
 {
 	if (is.function (method))
 		return (method) 
 	return  (eval (parse (text = method)))
 }
-
